@@ -4,6 +4,7 @@
 
 use std::ffi::c_void;
 use std::os::raw::c_char;
+use std::os::raw::c_uchar;
 
 #[allow(dead_code)]
 extern "C" {
@@ -274,7 +275,7 @@ extern "C" {
   /// Get the body data of a bytes message.
   pub fn tibemsBytesMsg_GetBytes(
     message: usize,
-    bytes: *const *const c_char,
+    bytes: *const *const c_uchar,
     byteSize: *mut u32) -> tibems_status;
   /// Set the body data of a bytes message from a byte sequence.
   pub fn tibemsBytesMsg_SetBytes(
@@ -545,6 +546,20 @@ extern "C" {
     enumeration: usize,
     name: *const *const c_char) -> tibems_status;
 
+  /// Create an object message.
+  pub fn tibemsObjectMsg_Create(
+    message: *mut usize) -> tibems_status;
+  /// Get the byte sequence representing a serialized object from a message. 
+  pub fn tibemsObjectMsg_GetObjectBytes(
+    message: usize,
+    bytes: *const *const c_char,
+    byteSize: *mut u32) -> tibems_status;
+  /// Set the byte sequence of an object message. 
+  pub fn tibemsObjectMsg_SetObjectBytes(
+    message: usize,
+    bytes: *const c_void,
+    byteSize: u32) -> tibems_status;
+
   /// Create a text message.
   pub fn tibemsTextMsg_Create(
     message: *mut usize) -> tibems_status;
